import {
  enqueue, log, reportError, logToDiscord,
} from '../core/utils';

export default function schedule(queueName: string, taskName: string, taskArguments: string[]): void {
  log(`[scheduling] Trying to schedule task ${taskName} in queue ${queueName} with args ${JSON.stringify(taskArguments)}`);
  enqueue(taskName, taskArguments, queueName)
    .then(() => {
      logToDiscord(`[scheduling] Task ${taskName} scheduled in queue ${queueName} with args ${JSON.stringify(taskArguments)}`);
    })
    .catch((error: Error) => {
      logToDiscord(`[scheduling] Task ${taskName} scheduling has failed`);
      reportError(error, { extra: { taskName, taskArguments, queueName } });
    })
    .then(() => {
      // Give time to logger to write buffer (probably should use pino.flush here instead)
      setTimeout(() => {
        process.nextTick(() => process.exit());
      }, 10);
    });
}
