import { db, Branch } from '../models';
import { log, reportError } from '../core/utils';
import { wk } from '../components/wikidot-kit';

export default async function run(): Promise<void> {
  log('Performing pages lists import');

  const branches = await Branch.query(db.replica);

  await Promise.all(branches.map(async (branch: Branch) => {
    const { name } = branch;
    try {
      const pagesList = await wk.fetchPagesList(name);
      await Branch
        .query(db.primary)
        .patch({ pagesList })
        .where({ name });
      log(`Pages list for wiki ${name} updated`);
    } catch (error) {
      reportError(error, {
        message: 'Error during pages list update',
        extra: { name },
      });
    }
  }));
  log('Pages list for all wikis updated');
}
